import BN from "bn.js";
import { TransactionSuccessStatus } from "../../types/genericMccTypes";
import { IUtxoGetTransactionRes, IUtxoTransactionAdditionalData, IUtxoVinTransaction, IUtxoVinVoutsMapper, IUtxoVoutTransaction } from "../../types/utxoTypes";
import { AddressAmount, TransactionBase } from "../TransactionBase";
export declare type UtxoTransactionTypeOptions = "coinbase" | "partial_payment" | "full_payment";
export declare abstract class UtxoTransaction<T> extends TransactionBase<T> {
    protected get data(): IUtxoGetTransactionRes;
    protected get additionalData(): IUtxoTransactionAdditionalData | undefined;
    protected set additionalData(data: IUtxoTransactionAdditionalData | undefined);
    get txid(): string;
    get stdTxid(): string;
    get hash(): string;
    get reference(): string[];
    get stdPaymentReference(): string;
    get unixTimestamp(): number;
    get sourceAddresses(): (string | undefined)[];
    get receivingAddresses(): (string | undefined)[];
    toBnValue(value: number | undefined): BN;
    reducerFunctionAdditionalDataVinOuts: (prev: BN, vout: IUtxoVinVoutsMapper | undefined) => BN;
    reducerFunctionPrevouts: (prev: BN, vin: IUtxoVinTransaction) => BN;
    reducerFunctionVouts: (prev: BN, vout: IUtxoVoutTransaction) => BN;
    get fee(): BN;
    get feeSignerTotalAmount(): AddressAmount;
    get spentAmounts(): AddressAmount[];
    get intendedSpentAmounts(): AddressAmount[];
    get receivedAmounts(): AddressAmount[];
    get intendedReceivedAmounts(): AddressAmount[];
    get type(): UtxoTransactionTypeOptions;
    get isNativePayment(): boolean;
    get elementaryUnits(): BN;
    get successStatus(): TransactionSuccessStatus;
    /**
     * Asserts whether the vin index is in valid range. If not, exception is thrown.
     * @param vinIndex vin index
     */
    assertValidVinIndex(vinIndex: number): void;
    /**
     * Asserts whether the vout index is in valid range. If not, exception is thrown.
     * @param voutIndex vout index
     */
    assertValidVoutIndex(voutIndex: number): void;
    /**
     * Extract vout on vout index. If vout index is not valid or data is corrupted, exception is thrown.
     * @param voutIndex vout index
     * @returns vout on vout index
     */
    extractVoutAt(voutIndex: number): IUtxoVoutTransaction;
}
//# sourceMappingURL=UtxoTransaction.d.ts.map