"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const src_1 = require("../../src");
const testUtils_1 = require("../testUtils");
const DogeMccConnection = {
    url: process.env.DOGE_URL || "",
    username: process.env.DOGE_USERNAME || "",
    password: process.env.DOGE_PASSWORD || "",
    apiTokenKey: process.env.FLARE_API_PORTAL_KEY || "",
};
describe(`Block DOGE process (${(0, testUtils_1.getTestFile)(__filename)})`, function () {
    let MccClient;
    const blockHeight = 4858845;
    before(async function () {
        MccClient = new src_1.MCC.DOGE(DogeMccConnection);
    });
    it("Should get block and check its height ", async function () {
        const block = await MccClient.getBlock(blockHeight);
        (0, chai_1.expect)(block.number).to.eq(blockHeight);
    });
    describe(`Processing transactions `, function () {
        let block;
        before(async function () {
            block = await MccClient.getFullBlock(blockHeight);
        });
        it("Should process all transactions ", async function () {
            let coinbase_indicator = true;
            for (const txid of block.transactionIds) {
                const tx = await MccClient.getTransaction(txid);
                await tx.makeFull((tid) => MccClient.getTransaction(tid));
                if (coinbase_indicator) {
                    (0, chai_1.expect)(tx.type).to.eq("coinbase");
                    coinbase_indicator = false;
                }
                else {
                    (0, chai_1.expect)(tx.type).to.eq("full_payment");
                }
            }
        });
    });
});
//# sourceMappingURL=processBlock.test.js.map